summaryrefslogtreecommitdiffstats
path: root/src/include/usr/errl/errlmanager.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/usr/errl/errlmanager.H')
-rw-r--r--src/include/usr/errl/errlmanager.H25
1 files changed, 20 insertions, 5 deletions
diff --git a/src/include/usr/errl/errlmanager.H b/src/include/usr/errl/errlmanager.H
index 07d4b79af..a5fcc136b 100644
--- a/src/include/usr/errl/errlmanager.H
+++ b/src/include/usr/errl/errlmanager.H
@@ -39,7 +39,6 @@
#include <util/singleton.H>
#include <errl/errlentry.H>
#include <errldisplay/errldisplay.H>
-#include <errl/errlipmi.H>
#include <sys/sync.h>
#include <kernel/timemgr.H>
#include <hbotcompid.H>
@@ -156,13 +155,15 @@ public:
static void errlResourceReady(errlManagerNeeds i_needs);
/**
* @brief Sends msg to errlmanager telling what resources are ready
*
- * This is called by resources that the ErrlManager needs, which start up
- * AFTER ErrlManager starts. Currently, that's PNOR MBOX and TARGeting.
+ * This is called by ipmi code once the SEL for the indicated errorlog
+ * has been successfully sent to the BMC
*
+ * It is a static function because a module cannot call an interface on a
+ * singleton in another module
*/
- void sendResourcesMsg(errlManagerNeeds i_needs);
+ static void errlAckErrorlog(uint32_t i_eid);
/**
* @brief Returns the HWAS ProcessCallout function pointer
@@ -250,6 +251,20 @@ private:
ErrlManager(const ErrlManager& i_right);
ErrlManager& operator=(const ErrlManager& i_right);
+ /**
+ * @brief Sends msg to errlmanager telling what resources are ready
+ *
+ * called by static errlResourceReady function.
+ */
+ void sendResourcesMsg(errlManagerNeeds i_needs);
+
+ /**
+ * @brief Sends msg to errlmanager telling which errlog to ack
+ *
+ * called by static errlAckErrorlog function.
+ */
+ void sendAckErrorlog(uint32_t i_eid);
+
/**
* @brief Access PNOR and get the address and size of the HBEL section in
* PNOR; sets the iv_pnorAddr, iv_maxErrlInPnor, iv_pnorOpenSlot variables;
@@ -156,13 +155,15 @@ public:
static void errlResourceReady(errlManagerNeeds i_needs);
/**
- * @brief Sends msg to errlmanager telling what resources are ready
+ * @brief Sends msg to errlmanager to ack sending of errl to BMC
*
OpenPOWER on IntegriCloud